[−][src]Enum unicode_types::domino_tiles::DominoTiles
An enum to represent all characters in the DominoTiles block.
Variants
DominoTileHorizontalBack\u{1f030}: '🀰'
DominoTileHorizontalDash00Dash00\u{1f031}: '🀱'
DominoTileHorizontalDash00Dash01\u{1f032}: '🀲'
DominoTileHorizontalDash00Dash02\u{1f033}: '🀳'
DominoTileHorizontalDash00Dash03\u{1f034}: '🀴'
DominoTileHorizontalDash00Dash04\u{1f035}: '🀵'
DominoTileHorizontalDash00Dash05\u{1f036}: '🀶'
DominoTileHorizontalDash00Dash06\u{1f037}: '🀷'
DominoTileHorizontalDash01Dash00\u{1f038}: '🀸'
DominoTileHorizontalDash01Dash01\u{1f039}: '🀹'
DominoTileHorizontalDash01Dash02\u{1f03a}: '🀺'
DominoTileHorizontalDash01Dash03\u{1f03b}: '🀻'
DominoTileHorizontalDash01Dash04\u{1f03c}: '🀼'
DominoTileHorizontalDash01Dash05\u{1f03d}: '🀽'
DominoTileHorizontalDash01Dash06\u{1f03e}: '🀾'
DominoTileHorizontalDash02Dash00\u{1f03f}: '🀿'
DominoTileHorizontalDash02Dash01\u{1f040}: '🁀'
DominoTileHorizontalDash02Dash02\u{1f041}: '🁁'
DominoTileHorizontalDash02Dash03\u{1f042}: '🁂'
DominoTileHorizontalDash02Dash04\u{1f043}: '🁃'
DominoTileHorizontalDash02Dash05\u{1f044}: '🁄'
DominoTileHorizontalDash02Dash06\u{1f045}: '🁅'
DominoTileHorizontalDash03Dash00\u{1f046}: '🁆'
DominoTileHorizontalDash03Dash01\u{1f047}: '🁇'
DominoTileHorizontalDash03Dash02\u{1f048}: '🁈'
DominoTileHorizontalDash03Dash03\u{1f049}: '🁉'
DominoTileHorizontalDash03Dash04\u{1f04a}: '🁊'
DominoTileHorizontalDash03Dash05\u{1f04b}: '🁋'
DominoTileHorizontalDash03Dash06\u{1f04c}: '🁌'
DominoTileHorizontalDash04Dash00\u{1f04d}: '🁍'
DominoTileHorizontalDash04Dash01\u{1f04e}: '🁎'
DominoTileHorizontalDash04Dash02\u{1f04f}: '🁏'
DominoTileHorizontalDash04Dash03\u{1f050}: '🁐'
DominoTileHorizontalDash04Dash04\u{1f051}: '🁑'
DominoTileHorizontalDash04Dash05\u{1f052}: '🁒'
DominoTileHorizontalDash04Dash06\u{1f053}: '🁓'
DominoTileHorizontalDash05Dash00\u{1f054}: '🁔'
DominoTileHorizontalDash05Dash01\u{1f055}: '🁕'
DominoTileHorizontalDash05Dash02\u{1f056}: '🁖'
DominoTileHorizontalDash05Dash03\u{1f057}: '🁗'
DominoTileHorizontalDash05Dash04\u{1f058}: '🁘'
DominoTileHorizontalDash05Dash05\u{1f059}: '🁙'
DominoTileHorizontalDash05Dash06\u{1f05a}: '🁚'
DominoTileHorizontalDash06Dash00\u{1f05b}: '🁛'
DominoTileHorizontalDash06Dash01\u{1f05c}: '🁜'
DominoTileHorizontalDash06Dash02\u{1f05d}: '🁝'
DominoTileHorizontalDash06Dash03\u{1f05e}: '🁞'
DominoTileHorizontalDash06Dash04\u{1f05f}: '🁟'
DominoTileHorizontalDash06Dash05\u{1f060}: '🁠'
DominoTileHorizontalDash06Dash06\u{1f061}: '🁡'
DominoTileVerticalBack\u{1f062}: '🁢'
DominoTileVerticalDash00Dash00\u{1f063}: '🁣'
DominoTileVerticalDash00Dash01\u{1f064}: '🁤'
DominoTileVerticalDash00Dash02\u{1f065}: '🁥'
DominoTileVerticalDash00Dash03\u{1f066}: '🁦'
DominoTileVerticalDash00Dash04\u{1f067}: '🁧'
DominoTileVerticalDash00Dash05\u{1f068}: '🁨'
DominoTileVerticalDash00Dash06\u{1f069}: '🁩'
DominoTileVerticalDash01Dash00\u{1f06a}: '🁪'
DominoTileVerticalDash01Dash01\u{1f06b}: '🁫'
DominoTileVerticalDash01Dash02\u{1f06c}: '🁬'
DominoTileVerticalDash01Dash03\u{1f06d}: '🁭'
DominoTileVerticalDash01Dash04\u{1f06e}: '🁮'
DominoTileVerticalDash01Dash05\u{1f06f}: '🁯'
DominoTileVerticalDash01Dash06\u{1f070}: '🁰'
DominoTileVerticalDash02Dash00\u{1f071}: '🁱'
DominoTileVerticalDash02Dash01\u{1f072}: '🁲'
DominoTileVerticalDash02Dash02\u{1f073}: '🁳'
DominoTileVerticalDash02Dash03\u{1f074}: '🁴'
DominoTileVerticalDash02Dash04\u{1f075}: '🁵'
DominoTileVerticalDash02Dash05\u{1f076}: '🁶'
DominoTileVerticalDash02Dash06\u{1f077}: '🁷'
DominoTileVerticalDash03Dash00\u{1f078}: '🁸'
DominoTileVerticalDash03Dash01\u{1f079}: '🁹'
DominoTileVerticalDash03Dash02\u{1f07a}: '🁺'
DominoTileVerticalDash03Dash03\u{1f07b}: '🁻'
DominoTileVerticalDash03Dash04\u{1f07c}: '🁼'
DominoTileVerticalDash03Dash05\u{1f07d}: '🁽'
DominoTileVerticalDash03Dash06\u{1f07e}: '🁾'
DominoTileVerticalDash04Dash00\u{1f07f}: '🁿'
DominoTileVerticalDash04Dash01\u{1f080}: '🂀'
DominoTileVerticalDash04Dash02\u{1f081}: '🂁'
DominoTileVerticalDash04Dash03\u{1f082}: '🂂'
DominoTileVerticalDash04Dash04\u{1f083}: '🂃'
DominoTileVerticalDash04Dash05\u{1f084}: '🂄'
DominoTileVerticalDash04Dash06\u{1f085}: '🂅'
DominoTileVerticalDash05Dash00\u{1f086}: '🂆'
DominoTileVerticalDash05Dash01\u{1f087}: '🂇'
DominoTileVerticalDash05Dash02\u{1f088}: '🂈'
DominoTileVerticalDash05Dash03\u{1f089}: '🂉'
DominoTileVerticalDash05Dash04\u{1f08a}: '🂊'
DominoTileVerticalDash05Dash05\u{1f08b}: '🂋'
DominoTileVerticalDash05Dash06\u{1f08c}: '🂌'
DominoTileVerticalDash06Dash00\u{1f08d}: '🂍'
DominoTileVerticalDash06Dash01\u{1f08e}: '🂎'
DominoTileVerticalDash06Dash02\u{1f08f}: '🂏'
DominoTileVerticalDash06Dash03\u{1f090}: '🂐'
DominoTileVerticalDash06Dash04\u{1f091}: '🂑'
DominoTileVerticalDash06Dash05\u{1f092}: '🂒'
DominoTileVerticalDash06Dash06\u{1f093}: '🂓'
Methods
impl DominoTiles[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case